@@ -40,15 +40,15 @@ class GraphicsBuilder:
         glEnable(GL_TEXTURE_2D)
         self.tex = glGenTextures(1)
 
-        self._load_texture('2.bmp', a_2)
-        self._load_texture('3.bmp', a_3)
-        self._load_texture('4.bmp', a_4)
-        self._load_texture('6.bmp', a_6)
-        self._load_texture('4i.bmp', a_4i)
-        self._load_texture('3i.bmp', a_3i)
-        self._load_texture('6i.bmp', a_6i)
+        self._load_texture('2.BMP', a_2)
+        self._load_texture('3.BMP', a_3)
+        self._load_texture('4.BMP', a_4)
+        self._load_texture('6.BMP', a_6)
+        self._load_texture('4i.BMP', a_4i)
+        self._load_texture('3i.BMP', a_3i)
+        self._load_texture('6i.BMP', a_6i)
 
-        self._load_texture('2SP.bmp', a_2sg)
+        self._load_texture('2SP.BMP', a_2sg)
         self._load_texture('21SPv.bmp', a_21sgv)
         self._load_texture('21SPh.bmp', a_21sgh)
 
